==> ejc-proequipmentcorp-impl-3.0.0-20221126.025525-189-sources.jar: com/ejianc/business/proequipmentcorpout/contract/bean/OutRentOtherDetailedEntity.java <==
package com.ejianc.business.proequipmentcorpout.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁其它费用明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_rent_other_detailed")
public class OutRentOtherDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="price")
    private BigDecimal price; // 
    @TableField(value="num")
    private Integer num; // 数量
    @TableField(value="tax_amount")
    private BigDecimal taxAmount; // 含税金额
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 单价无税
    @TableField(value="not_tax_amount")
    private BigDecimal notTaxAmount; // 金额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 税额
    @TableField(value="change_bid")
    private Long changeBid;//变更子表主键
    @TableField(value="change_id")
    private Long changeId;//变更子表主键

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public BigDecimal getNotTaxAmount() {
        return notTaxAmount;
    }

    public void setNotTaxAmount(BigDecimal notTaxAmount) {
        this.notTaxAmount = notTaxAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20230525.035006-412-sources.jar: com/ejianc/business/proequipmentcorpout/contract/bean/OutRentOtherDetailedEntity.java <==
package com.ejianc.business.proequipmentcorpout.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁其它费用明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_rent_other_detailed")
public class OutRentOtherDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="price")
    private BigDecimal price; // 
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="tax_amount")
    private BigDecimal taxAmount; // 含税金额
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 单价无税
    @TableField(value="not_tax_amount")
    private BigDecimal notTaxAmount; // 金额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 税额
    @TableField(value="change_bid")
    private Long changeBid;//变更子表主键
    @TableField(value="change_id")
    private Long changeId;//变更子表主键

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public BigDecimal getNotTaxAmount() {
        return notTaxAmount;
    }

    public void setNotTaxAmount(BigDecimal notTaxAmount) {
        this.notTaxAmount = notTaxAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
